# 010

|                                                                  | Asko induction hob 1   |
|:-----------------------------------------------------------------|:-----------------------|
| bindTime                                                         | 1637753665912          |
| createTime                                                       | 0                      |
| deviceFeatureCode                                                | 000                    |
| deviceFeatureName                                                | H-PIND-18              |
| deviceId                                                         | <redacted>             |
| deviceNickName                                                   | pind                   |
| deviceTypeCode                                                   | 010                    |
| deviceTypeName                                                   | \u7f51\u5173           |
| offlineState                                                     | 1                      |
| puid                                                             | <redacted>             |
| role                                                             | 1                      |
| roomId                                                           | 145444                 |
| roomName                                                         | CES 2022               |
| seq                                                              | 0                      |
| statusList.Air_dry_function                                      | 2                      |
| statusList.Alarm_Grease_filter                                   | 0                      |
| statusList.Alarm_NTC_TC                                          | 0                      |
| statusList.Alarm_NTC_coil_overheating                            | 0                      |
| statusList.Alarm_NTC_power                                       | 0                      |
| statusList.Alarm_Recirculation_filter_1                          | 0                      |
| statusList.Alarm_auto_program_ended                              | 0                      |
| statusList.Alarm_automatic_switch_off_zone                       | 0                      |
| statusList.Alarm_hob_hood_started                                | 0                      |
| statusList.Alarm_timer_ended                                     | 0                      |
| statusList.Alarm_voltage                                         | 0                      |
| statusList.Alarm_zone_turned_off                                 | 0                      |
| statusList.Auto_Grease_filter_indication                         | 0                      |
| statusList.Auto_Tower_Up                                         | 0                      |
| statusList.Auto_boost                                            | 1                      |
| statusList.Auto_bridge                                           | 1                      |
| statusList.Auto_timer                                            | 1                      |
| statusList.BuiltIn_Hood_status                                   | 1                      |
| statusList.Chef_mode                                             | 0                      |
| statusList.Child_lock                                            | 0                      |
| statusList.Circulation_mode                                      | 0                      |
| statusList.Circulation_mode__set_flag                            | 0                      |
| statusList.Control_Response_Level                                | 0                      |
| statusList.Demo_mode                                             | 0                      |
| statusList.Device_status                                         | 7                      |
| statusList.ECO_mode                                              | 0                      |
| statusList.Error_1                                               | 0                      |
| statusList.Error_10                                              | 0                      |
| statusList.Error_11                                              | 0                      |
| statusList.Error_12                                              | 0                      |
| statusList.Error_2                                               | 0                      |
| statusList.Error_3                                               | 0                      |
| statusList.Error_4                                               | 0                      |
| statusList.Error_5                                               | 0                      |
| statusList.Error_6                                               | 0                      |
| statusList.Error_7                                               | 0                      |
| statusList.Error_8                                               | 0                      |
| statusList.Error_9                                               | 0                      |
| statusList.FOTA_set                                              | 0                      |
| statusList.FOTA_set_flag                                         | 0                      |
| statusList.FOTA_status                                           | 0                      |
| statusList.Grease_Filter_saturation                              | 0                      |
| statusList.Grease_filter_cleaning_interval_in_hours              | 64256                  |
| statusList.Grease_filter_reset_counter                           | 0                      |
| statusList.Grease_filter_reset_counter_set_flag                  | 0                      |
| statusList.Grease_filter_set_lifetime_in_hours                   | 0                      |
| statusList.Grease_filter_set_lifetime_in_hours_set_flag          | 0                      |
| statusList.Grease_filter_status                                  | 3                      |
| statusList.Grease_filter_timer_active                            | 0                      |
| statusList.Grease_filter_timer_active_set_flag                   | 0                      |
| statusList.Grease_filter_used_hours                              | 0                      |
| statusList.HardPairingStatus                                     | 0                      |
| statusList.HardPairingUnpairAll                                  | 0                      |
| statusList.Hard_pairing_unpair_all_set_flag                      | 0                      |
| statusList.Hood_connected_via_RF                                 | 0                      |
| statusList.Hood_fan_speed                                        | 0                      |
| statusList.Hood_light                                            | 0                      |
| statusList.Hood_status                                           | 0                      |
| statusList.Hood_total_used_hours                                 | 0                      |
| statusList.Key_sensitivity_level                                 | 0                      |
| statusList.Key_sound_level                                       | 3                      |
| statusList.Motor                                                 | 0                      |
| statusList.Motor_level                                           | 85                     |
| statusList.Permanent_pot_detection                               | 1                      |
| statusList.Position_of_tower                                     | 0                      |
| statusList.Recirculation_filter_1_lifetime_in_hours              | 0                      |
| statusList.Recirculation_filter_1_reset_counter                  | 0                      |
| statusList.Recirculation_filter_1_reset_counter_set_flag         | 0                      |
| statusList.Recirculation_filter_1_set_lifetime_in_hours          | 0                      |
| statusList.Recirculation_filter_1_set_lifetime_in_hours_set_flag | 0                      |
| statusList.Recirculation_filter_1_set_type                       | 0                      |
| statusList.Recirculation_filter_1_set_type_set_flag              | 0                      |
| statusList.Recirculation_filter_1_status                         | 3                      |
| statusList.Recirculation_filter_1_timer_active                   | 0                      |
| statusList.Recirculation_filter_1_timer_active_set_flag          | 0                      |
| statusList.Recirculation_filter_1_type                           | 0                      |
| statusList.Recirculation_filter_1_used_hours                     | 0                      |
| statusList.Recovery                                              | 1                      |
| statusList.Remote_controlmode                                    | 0                      |
| statusList.SL1_Active_timer                                      | 0                      |
| statusList.SL1_Alarm_NTC_coil                                    | 0                      |
| statusList.SL1_Alarm_auto_program_notification                   | 0                      |
| statusList.SL1_Alarm_automatic_switch_off_zone                   | 0                      |
| statusList.SL1_Alarm_timer_ended                                 | 0                      |
| statusList.SL1_Alarm_zone_turned_off                             | 1                      |
| statusList.SL1_Bridge_function_active                            | 0                      |
| statusList.SL1_Bridged_to_zone                                   | 0                      |
| statusList.SL1_Cooking_method                                    | 0                      |
| statusList.SL1_Function_status                                   | 0                      |
| statusList.SL1_Functions                                         | 0                      |
| statusList.SL1_Hestan_Cue_Set_Temperature                        | 30                     |
| statusList.SL1_Hestan_Cue_Temperature                            | 30                     |
| statusList.SL1_Hestan_Cue_cookware_type                          | 0                      |
| statusList.SL1_Hestan_Cue_next_step_required_warning             | 0                      |
| statusList.SL1_NTC_sensor                                        | 25                     |
| statusList.SL1_Pot_detected                                      | 0                      |
| statusList.SL1_Power_level                                       | 0                      |
| statusList.SL1_Residual_heat_signal                              | 0                      |
| statusList.SL1_Sand_timer_UTC_start_time_hours                   | 23                     |
| statusList.SL1_Sand_timer_UTC_start_time_minutes                 | 59                     |
| statusList.SL1_Sand_timer_UTC_start_time_seconds                 | 59                     |
| statusList.SL1_Sand_timer_paused_total_seconds                   | 0                      |
| statusList.SL1_Sand_timer_status                                 | 0                      |
| statusList.SL1_Status                                            | 0                      |
| statusList.SL1_Stopwatch_UTC_start_time_hours                    | 23                     |
| statusList.SL1_Stopwatch_UTC_start_time_minutes                  | 59                     |
| statusList.SL1_Stopwatch_UTC_start_time_seconds                  | 59                     |
| statusList.SL1_Stopwatch_paused_total_seconds                    | 0                      |
| statusList.SL1_Stopwatch_status                                  | 0                      |
| statusList.SL1_Temperature                                       | 0                      |
| statusList.SL1_Timer_UTC_end_time_hours                          | 0                      |
| statusList.SL1_Timer_UTC_end_time_minutes                        | 0                      |
| statusList.SL1_Timer_UTC_end_time_seconds                        | 0                      |
| statusList.SL1_Timer_UTC_paused_hours                            | 0                      |
| statusList.SL1_Timer_UTC_paused_minutes                          | 0                      |
| statusList.SL1_Timer_UTC_paused_seconds                          | 0                      |
| statusList.SL1_error_1                                           | 0                      |
| statusList.SL1_error_10                                          | 0                      |
| statusList.SL1_error_11                                          | 0                      |
| statusList.SL1_error_12                                          | 0                      |
| statusList.SL1_error_13                                          | 0                      |
| statusList.SL1_error_14                                          | 0                      |
| statusList.SL1_error_15                                          | 0                      |
| statusList.SL1_error_16                                          | 0                      |
| statusList.SL1_error_17                                          | 0                      |
| statusList.SL1_error_2                                           | 0                      |
| statusList.SL1_error_3                                           | 0                      |
| statusList.SL1_error_4                                           | 0                      |
| statusList.SL1_error_5                                           | 0                      |
| statusList.SL1_error_6                                           | 0                      |
| statusList.SL1_error_7                                           | 0                      |
| statusList.SL1_error_8                                           | 0                      |
| statusList.SL1_error_9                                           | 0                      |
| statusList.SL2_Active_timer                                      | 0                      |
| statusList.SL2_Alarm_NTC_coil                                    | 0                      |
| statusList.SL2_Alarm_auto_program_notification                   | 0                      |
| statusList.SL2_Alarm_automatic_switch_off_zone                   | 0                      |
| statusList.SL2_Alarm_timer_ended                                 | 0                      |
| statusList.SL2_Alarm_zone_turned_off                             | 1                      |
| statusList.SL2_Bridge_function_active                            | 0                      |
| statusList.SL2_Bridged_to_zone                                   | 1                      |
| statusList.SL2_Cooking_method                                    | 0                      |
| statusList.SL2_Function_status                                   | 0                      |
| statusList.SL2_Functions                                         | 0                      |
| statusList.SL2_Hestan_Cue_Set_Temperature                        | 30                     |
| statusList.SL2_Hestan_Cue_Temperature                            | 30                     |
| statusList.SL2_Hestan_Cue_cookware_type                          | 0                      |
| statusList.SL2_Hestan_Cue_next_step_required_warning             | 0                      |
| statusList.SL2_NTC_sensor                                        | 25                     |
| statusList.SL2_Pot_detected                                      | 0                      |
| statusList.SL2_Power_level                                       | 0                      |
| statusList.SL2_Residual_heat_signal                              | 0                      |
| statusList.SL2_Sand_timer_UTC_start_time_hours                   | 23                     |
| statusList.SL2_Sand_timer_UTC_start_time_minutes                 | 59                     |
| statusList.SL2_Sand_timer_UTC_start_time_seconds                 | 59                     |
| statusList.SL2_Sand_timer_paused_total_seconds                   | 0                      |
| statusList.SL2_Sand_timer_status                                 | 0                      |
| statusList.SL2_Status                                            | 0                      |
| statusList.SL2_Stopwatch_UTC_start_time_hours                    | 23                     |
| statusList.SL2_Stopwatch_UTC_start_time_minutes                  | 59                     |
| statusList.SL2_Stopwatch_UTC_start_time_seconds                  | 59                     |
| statusList.SL2_Stopwatch_paused_total_seconds                    | 0                      |
| statusList.SL2_Stopwatch_status                                  | 0                      |
| statusList.SL2_Temperature                                       | 0                      |
| statusList.SL2_Timer_UTC_end_time_hours                          | 0                      |
| statusList.SL2_Timer_UTC_end_time_minutes                        | 0                      |
| statusList.SL2_Timer_UTC_end_time_seconds                        | 0                      |
| statusList.SL2_Timer_UTC_paused_hours                            | 0                      |
| statusList.SL2_Timer_UTC_paused_minutes                          | 0                      |
| statusList.SL2_Timer_UTC_paused_seconds                          | 0                      |
| statusList.SL2_error_1                                           | 0                      |
| statusList.SL2_error_10                                          | 0                      |
| statusList.SL2_error_11                                          | 0                      |
| statusList.SL2_error_12                                          | 0                      |
| statusList.SL2_error_13                                          | 0                      |
| statusList.SL2_error_14                                          | 0                      |
| statusList.SL2_error_15                                          | 0                      |
| statusList.SL2_error_16                                          | 0                      |
| statusList.SL2_error_17                                          | 0                      |
| statusList.SL2_error_2                                           | 0                      |
| statusList.SL2_error_3                                           | 0                      |
| statusList.SL2_error_4                                           | 0                      |
| statusList.SL2_error_5                                           | 0                      |
| statusList.SL2_error_6                                           | 0                      |
| statusList.SL2_error_7                                           | 0                      |
| statusList.SL2_error_8                                           | 0                      |
| statusList.SL2_error_9                                           | 0                      |
| statusList.SL3_Active_timer                                      | 0                      |
| statusList.SL3_Alarm_NTC_coil                                    | 0                      |
| statusList.SL3_Alarm_auto_program_notification                   | 0                      |
| statusList.SL3_Alarm_automatic_switch_off_zone                   | 0                      |
| statusList.SL3_Alarm_timer_ended                                 | 0                      |
| statusList.SL3_Alarm_zone_turned_off                             | 1                      |
| statusList.SL3_Bridge_function_active                            | 0                      |
| statusList.SL3_Bridged_to_zone                                   | 2                      |
| statusList.SL3_Cooking_method                                    | 0                      |
| statusList.SL3_Function_status                                   | 0                      |
| statusList.SL3_Functions                                         | 0                      |
| statusList.SL3_Hestan_Cue_Set_Temperature                        | 30                     |
| statusList.SL3_Hestan_Cue_Temperature                            | 30                     |
| statusList.SL3_Hestan_Cue_cookware_type                          | 0                      |
| statusList.SL3_Hestan_Cue_next_step_required_warning             | 0                      |
| statusList.SL3_NTC_sensor                                        | 24                     |
| statusList.SL3_Pot_detected                                      | 1                      |
| statusList.SL3_Power_level                                       | 0                      |
| statusList.SL3_Residual_heat_signal                              | 0                      |
| statusList.SL3_Sand_timer_UTC_start_time_hours                   | 23                     |
| statusList.SL3_Sand_timer_UTC_start_time_minutes                 | 59                     |
| statusList.SL3_Sand_timer_UTC_start_time_seconds                 | 59                     |
| statusList.SL3_Sand_timer_paused_total_seconds                   | 0                      |
| statusList.SL3_Sand_timer_status                                 | 0                      |
| statusList.SL3_Status                                            | 0                      |
| statusList.SL3_Stopwatch_UTC_start_time_hours                    | 23                     |
| statusList.SL3_Stopwatch_UTC_start_time_minutes                  | 59                     |
| statusList.SL3_Stopwatch_UTC_start_time_seconds                  | 59                     |
| statusList.SL3_Stopwatch_paused_total_seconds                    | 0                      |
| statusList.SL3_Stopwatch_status                                  | 0                      |
| statusList.SL3_Temperature                                       | 0                      |
| statusList.SL3_Timer_UTC_end_time_hours                          | 0                      |
| statusList.SL3_Timer_UTC_end_time_minutes                        | 0                      |
| statusList.SL3_Timer_UTC_end_time_seconds                        | 0                      |
| statusList.SL3_Timer_UTC_paused_hours                            | 0                      |
| statusList.SL3_Timer_UTC_paused_minutes                          | 0                      |
| statusList.SL3_Timer_UTC_paused_seconds                          | 0                      |
| statusList.SL3_error_1                                           | 0                      |
| statusList.SL3_error_10                                          | 0                      |
| statusList.SL3_error_11                                          | 0                      |
| statusList.SL3_error_12                                          | 0                      |
| statusList.SL3_error_13                                          | 0                      |
| statusList.SL3_error_14                                          | 0                      |
| statusList.SL3_error_15                                          | 0                      |
| statusList.SL3_error_16                                          | 0                      |
| statusList.SL3_error_17                                          | 0                      |
| statusList.SL3_error_2                                           | 0                      |
| statusList.SL3_error_3                                           | 0                      |
| statusList.SL3_error_4                                           | 0                      |
| statusList.SL3_error_5                                           | 0                      |
| statusList.SL3_error_6                                           | 0                      |
| statusList.SL3_error_7                                           | 0                      |
| statusList.SL3_error_8                                           | 0                      |
| statusList.SL3_error_9                                           | 0                      |
| statusList.SL4_Active_timer                                      | 0                      |
| statusList.SL4_Alarm_NTC_coil                                    | 0                      |
| statusList.SL4_Alarm_auto_program_notification                   | 0                      |
| statusList.SL4_Alarm_automatic_switch_off_zone                   | 0                      |
| statusList.SL4_Alarm_timer_ended                                 | 0                      |
| statusList.SL4_Alarm_zone_turned_off                             | 1                      |
| statusList.SL4_Bridge_function_active                            | 0                      |
| statusList.SL4_Bridged_to_zone                                   | 3                      |
| statusList.SL4_Cooking_method                                    | 0                      |
| statusList.SL4_Function_status                                   | 0                      |
| statusList.SL4_Functions                                         | 0                      |
| statusList.SL4_Hestan_Cue_Set_Temperature                        | 30                     |
| statusList.SL4_Hestan_Cue_Temperature                            | 30                     |
| statusList.SL4_Hestan_Cue_cookware_type                          | 0                      |
| statusList.SL4_Hestan_Cue_next_step_required_warning             | 0                      |
| statusList.SL4_NTC_sensor                                        | 25                     |
| statusList.SL4_Pot_detected                                      | 0                      |
| statusList.SL4_Power_level                                       | 0                      |
| statusList.SL4_Residual_heat_signal                              | 0                      |
| statusList.SL4_Sand_timer_UTC_start_time_hours                   | 23                     |
| statusList.SL4_Sand_timer_UTC_start_time_minutes                 | 59                     |
| statusList.SL4_Sand_timer_UTC_start_time_seconds                 | 59                     |
| statusList.SL4_Sand_timer_paused_total_seconds                   | 0                      |
| statusList.SL4_Sand_timer_status                                 | 0                      |
| statusList.SL4_Status                                            | 0                      |
| statusList.SL4_Stopwatch_UTC_start_time_hours                    | 23                     |
| statusList.SL4_Stopwatch_UTC_start_time_minutes                  | 59                     |
| statusList.SL4_Stopwatch_UTC_start_time_seconds                  | 59                     |
| statusList.SL4_Stopwatch_paused_total_seconds                    | 0                      |
| statusList.SL4_Stopwatch_status                                  | 0                      |
| statusList.SL4_Temperature                                       | 0                      |
| statusList.SL4_Timer_UTC_end_time_hours                          | 0                      |
| statusList.SL4_Timer_UTC_end_time_minutes                        | 0                      |
| statusList.SL4_Timer_UTC_end_time_seconds                        | 0                      |
| statusList.SL4_Timer_UTC_paused_hours                            | 0                      |
| statusList.SL4_Timer_UTC_paused_minutes                          | 0                      |
| statusList.SL4_Timer_UTC_paused_seconds                          | 0                      |
| statusList.SL4_error_1                                           | 0                      |
| statusList.SL4_error_10                                          | 0                      |
| statusList.SL4_error_11                                          | 0                      |
| statusList.SL4_error_12                                          | 0                      |
| statusList.SL4_error_13                                          | 0                      |
| statusList.SL4_error_14                                          | 0                      |
| statusList.SL4_error_15                                          | 0                      |
| statusList.SL4_error_16                                          | 0                      |
| statusList.SL4_error_17                                          | 0                      |
| statusList.SL4_error_2                                           | 0                      |
| statusList.SL4_error_3                                           | 0                      |
| statusList.SL4_error_4                                           | 0                      |
| statusList.SL4_error_5                                           | 0                      |
| statusList.SL4_error_6                                           | 0                      |
| statusList.SL4_error_7                                           | 0                      |
| statusList.SL4_error_8                                           | 0                      |
| statusList.SL4_error_9                                           | 0                      |
| statusList.SL5_Active_timer                                      | 0                      |
| statusList.SL5_Alarm_NTC_coil                                    | 0                      |
| statusList.SL5_Alarm_auto_program_notification                   | 0                      |
| statusList.SL5_Alarm_automatic_switch_off_zone                   | 0                      |
| statusList.SL5_Alarm_timer_ended                                 | 0                      |
| statusList.SL5_Alarm_zone_turned_off                             | 1                      |
| statusList.SL5_Bridge_function_active                            | 0                      |
| statusList.SL5_Bridged_to_zone                                   | 4                      |
| statusList.SL5_Cooking_method                                    | 0                      |
| statusList.SL5_Function_status                                   | 0                      |
| statusList.SL5_Functions                                         | 0                      |
| statusList.SL5_Hestan_Cue_Set_Temperature                        | 30                     |
| statusList.SL5_Hestan_Cue_Temperature                            | 30                     |
| statusList.SL5_Hestan_Cue_cookware_type                          | 0                      |
| statusList.SL5_Hestan_Cue_next_step_required_warning             | 0                      |
| statusList.SL5_NTC_sensor                                        | 25                     |
| statusList.SL5_Pot_detected                                      | 0                      |
| statusList.SL5_Power_level                                       | 0                      |
| statusList.SL5_Residual_heat_signal                              | 0                      |
| statusList.SL5_Sand_timer_UTC_start_time_hours                   | 23                     |
| statusList.SL5_Sand_timer_UTC_start_time_minutes                 | 59                     |
| statusList.SL5_Sand_timer_UTC_start_time_seconds                 | 59                     |
| statusList.SL5_Sand_timer_paused_total_seconds                   | 0                      |
| statusList.SL5_Sand_timer_status                                 | 0                      |
| statusList.SL5_Status                                            | 0                      |
| statusList.SL5_Stopwatch_UTC_start_time_hours                    | 23                     |
| statusList.SL5_Stopwatch_UTC_start_time_minutes                  | 59                     |
| statusList.SL5_Stopwatch_UTC_start_time_seconds                  | 59                     |
| statusList.SL5_Stopwatch_paused_total_seconds                    | 0                      |
| statusList.SL5_Stopwatch_status                                  | 0                      |
| statusList.SL5_Temperature                                       | 0                      |
| statusList.SL5_Timer_UTC_end_time_hours                          | 0                      |
| statusList.SL5_Timer_UTC_end_time_minutes                        | 0                      |
| statusList.SL5_Timer_UTC_end_time_seconds                        | 0                      |
| statusList.SL5_Timer_UTC_paused_hours                            | 0                      |
| statusList.SL5_Timer_UTC_paused_minutes                          | 0                      |
| statusList.SL5_Timer_UTC_paused_seconds                          | 0                      |
| statusList.SL5_error_1                                           | 0                      |
| statusList.SL5_error_10                                          | 0                      |
| statusList.SL5_error_11                                          | 0                      |
| statusList.SL5_error_12                                          | 0                      |
| statusList.SL5_error_13                                          | 0                      |
| statusList.SL5_error_14                                          | 0                      |
| statusList.SL5_error_15                                          | 0                      |
| statusList.SL5_error_16                                          | 0                      |
| statusList.SL5_error_17                                          | 0                      |
| statusList.SL5_error_2                                           | 0                      |
| statusList.SL5_error_3                                           | 0                      |
| statusList.SL5_error_4                                           | 0                      |
| statusList.SL5_error_5                                           | 0                      |
| statusList.SL5_error_6                                           | 0                      |
| statusList.SL5_error_7                                           | 0                      |
| statusList.SL5_error_8                                           | 0                      |
| statusList.SL5_error_9                                           | 0                      |
| statusList.SL6_Active_timer                                      | 0                      |
| statusList.SL6_Alarm_NTC_coil                                    | 0                      |
| statusList.SL6_Alarm_auto_program_notification                   | 0                      |
| statusList.SL6_Alarm_automatic_switch_off_zone                   | 0                      |
| statusList.SL6_Alarm_timer_ended                                 | 0                      |
| statusList.SL6_Alarm_zone_turned_off                             | 0                      |
| statusList.SL6_Bridge_function_active                            | 0                      |
| statusList.SL6_Bridged_to_zone                                   | 0                      |
| statusList.SL6_Cooking_method                                    | 0                      |
| statusList.SL6_Function_status                                   | 0                      |
| statusList.SL6_Functions                                         | 0                      |
| statusList.SL6_Hestan_Cue_Set_Temperature                        | 30                     |
| statusList.SL6_Hestan_Cue_Temperature                            | 30                     |
| statusList.SL6_Hestan_Cue_cookware_type                          | 0                      |
| statusList.SL6_Hestan_Cue_next_step_required_warning             | 0                      |
| statusList.SL6_NTC_sensor                                        | 0                      |
| statusList.SL6_Pot_detected                                      | 0                      |
| statusList.SL6_Power_level                                       | 0                      |
| statusList.SL6_Residual_heat_signal                              | 0                      |
| statusList.SL6_Sand_timer_UTC_start_time_hours                   | 0                      |
| statusList.SL6_Sand_timer_UTC_start_time_minutes                 | 0                      |
| statusList.SL6_Sand_timer_UTC_start_time_seconds                 | 0                      |
| statusList.SL6_Sand_timer_paused_total_seconds                   | 0                      |
| statusList.SL6_Sand_timer_status                                 | 0                      |
| statusList.SL6_Status                                            | 0                      |
| statusList.SL6_Stopwatch_UTC_start_time_hours                    | 0                      |
| statusList.SL6_Stopwatch_UTC_start_time_minutes                  | 0                      |
| statusList.SL6_Stopwatch_UTC_start_time_seconds                  | 0                      |
| statusList.SL6_Stopwatch_paused_total_seconds                    | 0                      |
| statusList.SL6_Stopwatch_status                                  | 0                      |
| statusList.SL6_Temperature                                       | 0                      |
| statusList.SL6_Timer_UTC_end_time_hours                          | 0                      |
| statusList.SL6_Timer_UTC_end_time_minutes                        | 0                      |
| statusList.SL6_Timer_UTC_end_time_seconds                        | 0                      |
| statusList.SL6_Timer_UTC_paused_hours                            | 0                      |
| statusList.SL6_Timer_UTC_paused_minutes                          | 0                      |
| statusList.SL6_Timer_UTC_paused_seconds                          | 0                      |
| statusList.SL6_error_1                                           | 0                      |
| statusList.SL6_error_10                                          | 0                      |
| statusList.SL6_error_11                                          | 0                      |
| statusList.SL6_error_12                                          | 0                      |
| statusList.SL6_error_13                                          | 0                      |
| statusList.SL6_error_14                                          | 0                      |
| statusList.SL6_error_15                                          | 0                      |
| statusList.SL6_error_16                                          | 0                      |
| statusList.SL6_error_17                                          | 0                      |
| statusList.SL6_error_2                                           | 0                      |
| statusList.SL6_error_3                                           | 0                      |
| statusList.SL6_error_4                                           | 0                      |
| statusList.SL6_error_5                                           | 0                      |
| statusList.SL6_error_6                                           | 0                      |
| statusList.SL6_error_7                                           | 0                      |
| statusList.SL6_error_8                                           | 0                      |
| statusList.SL6_error_9                                           | 0                      |
| statusList.Stand_by_time                                         | 0                      |
| statusList.Synchro_Start_Level                                   | 0                      |
| statusList.Synchro_Stop_Level                                    | 0                      |
| statusList.Test_mode                                             | 0                      |
| statusList.Total_time_of_cooking_in_minute                       | 1629                   |
| statusList.Window_status                                         | 1                      |
| statusList.daily_energy_kwh                                      | 0                      |
| useTime                                                          | 0                      |
| wifiId                                                           | <redacted>             |

## Generated from

- [`Asko_induction_hob_1.json`](Asko_induction_hob_1.json)
